@@ -864,6 +864,7 @@ func NewNodeGroup() *NodeGroup {
 					FSX:                       Disabled(),
 					EFS:                       Disabled(),
 					AWSLoadBalancerController: Disabled(),
+					DeprecatedALBIngress:      Disabled(),
 					XRay:                      Disabled(),
 					CloudWatch:                Disabled(),
 				},
@@ -913,6 +914,7 @@ func NewManagedNodeGroup() *ManagedNodeGroup {
 					FSX:                       Disabled(),
 					EFS:                       Disabled(),
 					AWSLoadBalancerController: Disabled(),
+					DeprecatedALBIngress:      Disabled(),
 					XRay:                      Disabled(),
 					CloudWatch:                Disabled(),
 				},
@@ -934,7 +936,7 @@ func (c *ClusterConfig) NewNodeGroup() *NodeGroup {
 }
 
 // NodeGroup holds configuration attributes that are
-// specific to a nodegroup
+// specific to an unmanaged nodegroup
 type NodeGroup struct {
 	*NodeGroupBase
 
@@ -977,6 +979,10 @@ type NodeGroup struct {
 	// ContainerRuntime defines the runtime (CRI) to use for containers on the node
 	// +optional
 	ContainerRuntime *string `json:"containerRuntime,omitempty"`
+
+	// MaxInstanceLifetime defines the maximum amount of time in seconds an instance stays alive.
+	// +optional
+	MaxInstanceLifetime *int `json:"maxInstanceLifetime,omitempty"`
 }
 
 // GetContainerRuntime returns the container runtime.
@@ -1107,7 +1113,9 @@ type (
 		// +optional
 		EFS *bool `json:"efs"`
 		// +optional
-		AWSLoadBalancerController *bool `json:"albIngress"`
+		AWSLoadBalancerController *bool `json:"awsLoadBalancerController"`
+		// +optional
+		DeprecatedALBIngress *bool `json:"albIngress"`
 		// +optional
 		XRay *bool `json:"xRay"`
 		// +optional
