@@ -122,6 +122,16 @@ var _ = Describe("Unmanaged NodeGroup Template Builder", func() {
 			})
 		})
 
+		Context("if ng.MaxInstanceLifetime is set", func() {
+			BeforeEach(func() {
+				ng.MaxInstanceLifetime = aws.Int(api.OneDay)
+			})
+
+			It("sets the desired value", func() {
+				Expect(ngTemplate.Resources["NodeGroup"].Properties.MaxInstanceLifetime).To(Equal(api.OneDay))
+			})
+		})
+
 		Context("if ng.MaxSize is nil", func() {
 			BeforeEach(func() {
 				ng.MaxSize = nil
@@ -484,6 +494,19 @@ var _ = Describe("Unmanaged NodeGroup Template Builder", func() {
 				})
 			})
 
+			Context("ng.WithAddonPolicies.DeprecatedALBIngress is set", func() {
+				BeforeEach(func() {
+					ng.IAM.WithAddonPolicies.DeprecatedALBIngress = aws.Bool(true)
+				})
+
+				It("adds PolicyAWSLoadBalancerController to the role", func() {
+					Expect(ngTemplate.Resources).To(HaveKey("PolicyAWSLoadBalancerController"))
+
+					Expect(ngTemplate.Resources["PolicyAWSLoadBalancerController"].Properties.Roles).To(HaveLen(1))
+					Expect(isRefTo(ngTemplate.Resources["PolicyAWSLoadBalancerController"].Properties.Roles[0], "NodeInstanceRole")).To(BeTrue())
+				})
+			})
+
 			Context("ng.WithAddonPolicies.XRay is set", func() {
 				BeforeEach(func() {
 					ng.IAM.WithAddonPolicies.XRay = aws.Bool(true)
