@@ -14,11 +14,10 @@ import (
 	"github.com/pkg/errors"
 	"github.com/tidwall/gjson"
 
-	"github.com/weaveworks/eksctl/pkg/nodebootstrap"
-
 	api "github.com/weaveworks/eksctl/pkg/apis/eksctl.io/v1alpha5"
 	"github.com/weaveworks/eksctl/pkg/cfn/builder"
 	"github.com/weaveworks/eksctl/pkg/cfn/outputs"
+	"github.com/weaveworks/eksctl/pkg/nodebootstrap"
 	"github.com/weaveworks/eksctl/pkg/version"
 	"github.com/weaveworks/eksctl/pkg/vpc"
 )
@@ -42,12 +41,14 @@ type NodeGroupSummary struct {
 	NodeInstanceRoleARN  string
 	AutoScalingGroupName string
 	Version              string
+	NodeGroupType        api.NodeGroupType `json:"Type"`
 }
 
 // NodeGroupStack represents a nodegroup and its type
 type NodeGroupStack struct {
 	NodeGroupName string
 	Type          api.NodeGroupType
+	Stack         *Stack
 }
 
 // makeNodeGroupStackName generates the name of the nodegroup stack identified by its name, isolated by the cluster this StackCollection operates on
@@ -141,6 +142,7 @@ func (c *StackCollection) ListNodeGroupStacks() ([]NodeGroupStack, error) {
 		nodeGroupStacks = append(nodeGroupStacks, NodeGroupStack{
 			NodeGroupName: c.GetNodeGroupName(stack),
 			Type:          nodeGroupType,
+			Stack:         stack,
 		})
 	}
 	return nodeGroupStacks, nil
@@ -160,17 +162,12 @@ func (c *StackCollection) DescribeNodeGroupStacksAndResources() (map[string]Stac
 		input := &cfn.DescribeStackResourcesInput{
 			StackName: s.StackName,
 		}
-		template, err := c.GetStackTemplate(*s.StackName)
-		if err != nil {
-			return nil, errors.Wrapf(err, "getting template for %q stack", *s.StackName)
-		}
 		resources, err := c.cloudformationAPI.DescribeStackResources(input)
 		if err != nil {
 			return nil, errors.Wrapf(err, "getting all resources for %q stack", *s.StackName)
 		}
 		allResources[c.GetNodeGroupName(s)] = StackInfo{
 			Resources: resources.StackResources,
-			Template:  &template,
 			Stack:     s,
 		}
 	}
@@ -207,6 +204,7 @@ func (c *StackCollection) GetUnmanagedNodeGroupSummaries(name string) ([]*NodeGr
 		if err != nil {
 			return nil, errors.Wrap(err, "mapping stack to nodegroup summary")
 		}
+		summary.NodeGroupType = api.NodeGroupTypeUnmanaged
 
 		asgName, err := c.getUnmanagedNodeGroupAutoScalingGroupName(s)
 		if err != nil {
@@ -319,10 +317,19 @@ func (c *StackCollection) DescribeNodeGroupStack(nodeGroupName string) (*Stack,
 }
 
 // GetNodeGroupStackType returns the nodegroup stack type
-func (c *StackCollection) GetNodeGroupStackType(name string) (api.NodeGroupType, error) {
-	stack, err := c.DescribeNodeGroupStack(name)
-	if err != nil {
-		return "", err
+func (c *StackCollection) GetNodeGroupStackType(options GetNodegroupOption) (api.NodeGroupType, error) {
+	var (
+		err   error
+		stack *Stack
+	)
+	if options.Stack != nil && options.Stack.Stack != nil {
+		stack = options.Stack.Stack
+	}
+	if stack == nil {
+		stack, err = c.DescribeNodeGroupStack(options.NodeGroupName)
+		if err != nil {
+			return "", err
+		}
 	}
 	return GetNodeGroupType(stack.Tags)
 }
