@@ -84,11 +84,7 @@ func doGetIdentityProvider(cmd *cmdutils.Cmd, params getCmdParams, name string)
 		addIdentityProviderTableColumns(printer.(*printers.TablePrinter), len(summaries))
 	}
 
-	if err := printer.PrintObjWithKind("identity provider summary", summaries, os.Stdout); err != nil {
-		return err
-	}
-
-	return nil
+	return printer.PrintObjWithKind("identity provider summary", summaries, os.Stdout)
 }
 
 func addIdentityProviderTableColumns(printer *printers.TablePrinter, num int) {
