@@ -1,12 +1,9 @@
 package eks_test
 
 import (
-	"fmt"
-
 	"github.com/aws/aws-sdk-go/aws"
 	"github.com/aws/aws-sdk-go/aws/awserr"
 	cfn "github.com/aws/aws-sdk-go/service/cloudformation"
-	"github.com/aws/aws-sdk-go/service/ec2"
 	awseks "github.com/aws/aws-sdk-go/service/eks"
 	"github.com/kris-nova/logger"
 
@@ -171,223 +168,6 @@ var _ = Describe("EKS API wrapper", func() {
 
 	})
 
-	Describe("ListClusters", func() {
-		var (
-			err            error
-			chunkSize      int
-			listAllRegions bool
-			clusters       []*api.ClusterConfig
-		)
-
-		BeforeEach(func() {
-			p = mockprovider.NewMockProvider()
-			c = &ClusterProvider{
-				Provider: p,
-			}
-			listAllRegions = false
-		})
-
-		When("and chunk-size of 1", func() {
-			When("the clusters are not eksctl created", func() {
-
-				var (
-					callNumber int
-				)
-				BeforeEach(func() {
-					chunkSize = 1
-					callNumber = 0
-
-					mockResultFn := func(_ *awseks.ListClustersInput) *awseks.ListClustersOutput {
-						clusterName := fmt.Sprintf("cluster-%d", callNumber)
-						output := &awseks.ListClustersOutput{
-							Clusters: []*string{aws.String(clusterName)},
-						}
-						if callNumber == 0 {
-							output.NextToken = aws.String("SOMERANDOMTOKEN")
-						}
-
-						callNumber++
-						return output
-					}
-
-					p.MockEKS().On("ListClusters", mock.MatchedBy(func(input *awseks.ListClustersInput) bool {
-						return *input.MaxResults == int64(chunkSize)
-					})).Return(mockResultFn, nil)
-
-					p.MockCloudFormation().On("ListStacksPages", mock.Anything, mock.Anything).Return(nil)
-				})
-
-				JustBeforeEach(func() {
-					clusters, err = c.ListClusters(chunkSize, listAllRegions, nil)
-				})
-
-				It("should not error", func() {
-					Expect(err).NotTo(HaveOccurred())
-				})
-
-				It("should return a list of clusters", func() {
-					Expect(clusters).To(ConsistOf(
-						&api.ClusterConfig{
-							Metadata: &api.ClusterMeta{
-								Name:   "cluster-0",
-								Region: c.Provider.Region(),
-							},
-							Status: &api.ClusterStatus{
-								EKSCTLCreated: "False",
-							},
-						},
-						&api.ClusterConfig{
-							Metadata: &api.ClusterMeta{
-								Name:   "cluster-1",
-								Region: c.Provider.Region(),
-							},
-							Status: &api.ClusterStatus{
-								EKSCTLCreated: "False",
-							},
-						},
-					))
-				})
-
-				It("should have called AWS EKS service twice", func() {
-					p.MockEKS().AssertNumberOfCalls(GinkgoT(), "ListClusters", 2)
-				})
-
-				It("should check if the clusters are eksctl created", func() {
-					p.MockCloudFormation().AssertNumberOfCalls(GinkgoT(), "ListStacksPages", 1)
-				})
-			})
-		})
-
-		Context("and chunk-size of 100", func() {
-			BeforeEach(func() {
-				chunkSize = 100
-
-				mockResultFn := func(_ *awseks.ListClustersInput) *awseks.ListClustersOutput {
-					output := &awseks.ListClustersOutput{
-						Clusters: []*string{aws.String("cluster-1"), aws.String("cluster-2")},
-					}
-					return output
-				}
-
-				p.MockEKS().On("ListClusters", mock.MatchedBy(func(input *awseks.ListClustersInput) bool {
-					return *input.MaxResults == int64(chunkSize)
-				})).Return(mockResultFn, nil)
-
-				p.MockCloudFormation().On("ListStacksPages", mock.Anything, mock.Anything).Return(nil)
-			})
-
-			JustBeforeEach(func() {
-				clusters, err = c.ListClusters(chunkSize, listAllRegions, nil)
-			})
-
-			It("should not error", func() {
-				Expect(err).NotTo(HaveOccurred())
-			})
-
-			It("should have called AWS EKS service once", func() {
-				p.MockEKS().AssertNumberOfCalls(GinkgoT(), "ListClusters", 1)
-			})
-		})
-
-		Context("listAllRegions is true", func() {
-			BeforeEach(func() {
-				chunkSize = 100
-				listAllRegions = true
-
-				p.MockEC2().On("DescribeRegions", mock.Anything).Return(&ec2.DescribeRegionsOutput{}, nil)
-			})
-
-			JustBeforeEach(func() {
-				clusters, err = c.ListClusters(chunkSize, listAllRegions, func(_ *api.ProviderConfig, _ *api.ClusterConfig) (*ClusterProvider, error) {
-					return &ClusterProvider{
-						Provider: p,
-					}, nil
-				})
-			})
-
-			It("should have called AWS EC2 service once", func() {
-				p.MockEC2().AssertNumberOfCalls(GinkgoT(), "DescribeRegions", 1)
-			})
-		})
-
-		Context("listAllRegions is true and account has access to unsupported EKS regions", func() {
-			expectedRegions := map[string]struct{}{}
-
-			BeforeEach(func() {
-				listAllRegions = true
-				unsupportedRegion := "ap-southeast-3"
-
-				var regionsOutput []*ec2.Region
-				for _, r := range api.SupportedRegions() {
-					if r == unsupportedRegion {
-						Fail(fmt.Sprintf("Region %s is now supported", unsupportedRegion))
-					}
-					expectedRegions[r] = struct{}{}
-					regionsOutput = append(regionsOutput, &ec2.Region{
-						RegionName: aws.String(r),
-					})
-				}
-
-				regionsOutput = append(regionsOutput, &ec2.Region{
-					RegionName: aws.String(unsupportedRegion),
-				})
-
-				p.MockEC2().On("DescribeRegions", mock.Anything).Return(&ec2.DescribeRegionsOutput{
-					Regions: regionsOutput,
-				}, nil)
-
-				p.MockCloudFormation().On("ListStacksPages", mock.Anything, mock.Anything).Return(nil)
-				p.MockEKS().On("ListClusters", mock.Anything).Return(&awseks.ListClustersOutput{}, nil)
-			})
-
-			It("should list clusters", func() {
-				clusters, err = c.ListClusters(chunkSize, listAllRegions, func(pc *api.ProviderConfig, _ *api.ClusterConfig) (*ClusterProvider, error) {
-					if _, ok := expectedRegions[pc.Region]; !ok {
-						return nil, fmt.Errorf("unsupported region: %s", pc.Region)
-					}
-					return &ClusterProvider{
-						Provider: p,
-					}, nil
-				})
-
-				Expect(err).NotTo(HaveOccurred())
-				Expect(clusters).To(BeEmpty())
-				p.MockEKS().AssertNumberOfCalls(GinkgoT(), "ListClusters", len(api.SupportedRegions()))
-			})
-		})
-	})
-
-	Describe("ListClusters when no clusters exist", func() {
-		It("should return empty slice", func() {
-			p = mockprovider.NewMockProvider()
-
-			c = &ClusterProvider{
-				Provider: p,
-				Status:   &ProviderStatus{},
-			}
-
-			mockResultFn := func(_ *awseks.ListClustersInput) *awseks.ListClustersOutput {
-				output := &awseks.ListClustersOutput{
-					Clusters: []*string{},
-				}
-				return output
-			}
-
-			chunkSize := 1
-
-			p.MockEKS().On("ListClusters", mock.MatchedBy(func(input *awseks.ListClustersInput) bool {
-				return *input.MaxResults == int64(chunkSize)
-			})).Return(mockResultFn, nil)
-
-			p.MockCloudFormation().On("ListStacksPages", mock.Anything, mock.Anything).Return(nil)
-
-			clusters, err := c.ListClusters(chunkSize, false, nil)
-			Expect(err).NotTo(HaveOccurred())
-			Expect(clusters).NotTo(BeNil())
-			Expect(len(clusters)).To(Equal(0))
-		})
-	})
-
 	Describe("can get OIDC issuer URL and host fingerprint", func() {
 		var (
 			ctl *ClusterProvider
