@@ -204,7 +204,7 @@ func describeVPC(ec2API ec2iface.EC2API, vpcID string) (*ec2.Vpc, error) {
 // is treated as the source of truth
 func UseFromClusterStack(provider api.ClusterProvider, stack *cfn.Stack, spec *api.ClusterConfig) error {
 	if spec.VPC == nil {
-		spec.VPC = api.NewClusterVPC()
+		spec.VPC = api.NewClusterVPC(spec.IPv6Enabled())
 	}
 	// this call is authoritative, and we can safely override the
 	// CIDR, as it can only be set to anything due to defaulting
@@ -532,7 +532,7 @@ func validatePublicSubnet(subnets []*ec2.Subnet) error {
 		}
 	}
 	if len(legacySubnets) > 0 {
-		return fmt.Errorf("found mis-configured subnets %q. Expected public subnets with property "+
+		return fmt.Errorf("found mis-configured or non-public subnets %q. Expected public subnets with property "+
 			"\"MapPublicIpOnLaunch\" enabled. Without it new nodes won't get an IP assigned", legacySubnets)
 	}
 
